@@ -79,7 +79,7 @@ class Memcached extends AbstractAdapter implements
 
         // reset initialized flag on update option(s)
         $initialized = & $this->initialized;
-        $this->getEventManager()->attach('option', function ($event) use (& $initialized) {
+        $this->getEventManager()->attach('option', function () use (& $initialized) {
             $initialized = false;
         });
     }
